@@ -5,7 +5,7 @@ oer - IRC bot
 See ftp://nic.funet.fi/pub/unix/irc/docs/FAQ.gz section 11 for the
 definition of the word bot.
 
-Copyright (C) 2000 EQU <equ@equnet.org>
+Copyright (C) 2000-2001 EQU <equ@equnet.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -271,17 +271,43 @@ void parseirc(char *serveroutput)
 	}
 	if(!strcasecmp(command, "433")) {
 		if(mystate->use_alt_nick) {
-                        oer_debug(OER_DEBUG_INFO, "parseirc(433)->both our primary and secondary nicknames are taken, generating a random nick\n");
+                        oer_debug(OER_DEBUG_INFO, "parseirc(%s)->both our primary and secondary nicknames are taken, generating a random nick\n", command);
                         snprintf(mystate->nick, NICKLEN, "oer-%d", getrandom(9999));
                         mystate->use_alt_nick = 0;
 			mystate->current_server->registered = OER_REGISTERCONNECTION_STATUS_BEGIN;
                         return;
                 }
-		oer_debug(OER_DEBUG_INFO, "parseirc(433)->our nickname %s is already in use, will try altnick %s\n", mystate->nick, mystate->altnick);
+		oer_debug(OER_DEBUG_INFO, "parseirc(%s)->our nickname %s is already in use, will try altnick %s\n", command, mystate->nick, mystate->altnick);
 		mystate->use_alt_nick = 1;
 		mystate->current_server->registered = OER_REGISTERCONNECTION_STATUS_BEGIN;
 		return;
 	}
+	if(!strcasecmp(command, "437")) {
+		/* ERR_UNAVAILRESOURCE, handle both cases */
+		restpos = 0;
+		if((restpos = parse(restptr, restpos, " ", channel, CHANLEN, 0)) < 0) {
+			return;
+		}
+		oer_debug(OER_DEBUG_INFO, "parseirc(%s)->%s\n", command, channel);
+		if((this = getchptr(channel)) == NULL) {
+			/* no channel meaning nick is unavailable */
+			if(mystate->use_alt_nick) {
+				oer_debug(OER_DEBUG_INFO, "parseirc(%s)->both our primary and secondary nicknames are taken, generating a random nick\n", command);
+				snprintf(mystate->nick, NICKLEN, "oer-%d", getrandom(9999));
+				mystate->use_alt_nick = 0;
+				mystate->current_server->registered = OER_REGISTERCONNECTION_STATUS_BEGIN;
+				return;
+			}
+			oer_debug(OER_DEBUG_INFO, "parseirc(%s)->our nickname %s is already in use, will try altnick %s\n", command, mystate->nick, mystate->altnick);
+			mystate->use_alt_nick = 1;
+			mystate->current_server->registered = OER_REGISTERCONNECTION_STATUS_BEGIN;
+			return;
+		}
+		/* we got channel, reset joining flag */
+		this->rejoin_at = mystate->now + OER_AUTO_REJOIN_TIME;
+		this->joining = 0;
+                return;
+        }
 	if(!strcasecmp(command, "439")) {
 		oer_debug(OER_DEBUG_INFO, "parseirc(439)->%s\n", restptr);
                 return;
@@ -740,6 +766,8 @@ void parsemsg(char *nick, char *host, char *target, char *message)
 {
 	int ctcp;
 	int ppos;
+	int is_command;
+	char active_nick[NICKLEN + 1];
 
 	oer_debug(OER_DEBUG_INFO, "parsemsg->%s!%s target: %s message: %s\n", nick, host, target, message);
 	ctcp = 0;
@@ -806,16 +834,35 @@ void parsemsg(char *nick, char *host, char *target, char *message)
 		/* we don't log ctcp (not even ACTIONS) */
 		return;
 	}
+	/* check for command */
+	is_command = 0;
+	ppos = 0;
+	strncpy(active_nick, mystate->nick, NICKLEN);
+	if(mystate->use_alt_nick) {
+		strncpy(active_nick, mystate->altnick, NICKLEN);
+	}
+	if(!strncasecmp(message, active_nick, strlen(active_nick))) {
+		is_command = 1;
+                ppos = strlen(active_nick);
+                if(isspace((int)message[ppos])) {
+                        while(isspace((int)message[ppos])) {
+                                ppos++;
+                        }
+                }
+        }
 	if(!strncasecmp(message, mystate->prefix, strlen(mystate->prefix))) {
+		is_command = 1;
                 ppos = strlen(mystate->prefix);
                 if(isspace((int)message[ppos])) {
                         while(isspace((int)message[ppos])) {
                                 ppos++;
                         }
                 }
-                /* here is when we parse all commands */
-                parsecommand(target, nick, host, message + ppos);
         }
+	if(is_command) {
+		/* here is when we parse all commands */
+		parsecommand(target, nick, host, message + ppos);
+	}
 	if(hasuserflags(target, host, "x")) {
 		/* user's messages won't be saved */
 		oer_debug(OER_DEBUG_INFO, "parsemsg->messages from %s to %s won't be saved\n", nick, target);
